16.111. cdist-type__package_pkgng_freebsd(7) — cdist 6.9.4 documentation

# 16.111. cdist-type__package_pkgng_freebsd(7)

## 16.111.1. NAME

cdist-type__package_pkgng_freebsd - Manage FreeBSD packages with pkg-ng

## 16.111.2. DESCRIPTION

This type is usually used on FreeBSD to manage packages.

## 16.111.3. REQUIRED PARAMETERS

None

## 16.111.4. OPTIONAL PARAMETERS

name

  If supplied, use the name and not the object id as the package name.

flavor

  If supplied, use to avoid ambiguity.

version

  If supplied, use to install a specific version of the package named.

repo

  If supplied, use to install the package named from a particular repo.

state

  Either "present" or "absent", defaults to "present"

## 16.111.5. BOOLEAN PARAMETERS

upgrade

  If supplied, allow upgrading to the latest version of a package.

## 16.111.6. CAVEATS

This type requires that repository definitions already exist in /etc/pkg/*.conf. Ensure that they exist prior to use of this type with __file.

pkg-ng can't upgrade a package to a specific version. If this type needs to upgrade a package, it can only ugprade to the latest available version. If the "upgrade" parameter is not given and an upgrade needs to occur, an error will result.

## 16.111.7. MESSAGES

install

  The package was installed

remove

  The package was removed

upgrade

  The package was upgraded

exist

  The package was already present and thus not installed

## 16.111.8. EXAMPLES

    # Ensure zsh is installed
    __package_pkgng_freebsd zsh --state present

    # Ensure vim is installed, use flavor no_x11
    __package_pkgng_freebsd vim --state present --flavor no_x11

    # If you don't want to follow pythonX packages, but always use python
    __package_pkgng_freebsd python --state present --name python2

    # Install a package from a particular repository when multiples exist
    __package_pkgng_freebsd bash --state present --repo myrepo

    # Remove obsolete package
    __package_pkgng_freebsd puppet --state absent

## 16.111.9. SEE ALSO

cdist-type__package(7)

## 16.111.10. AUTHORS

Jake Guffey <jake.guffey--@--eprotex.com>

## 16.111.11. COPYING

Copyright (C) 2014 Jake Guffey. You can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation, either version 3 of the License, or (at your option) any later version.